<?php

/*
 * LMS version 1.11.7 Bastet
 *
 *  (C) Copyright 2001-2009 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: aliasdel.php,v 1.13 2009/01/13 07:45:47 alec Exp $
 */

$id = $_GET['id'];

if($id && $_GET['is_sure']=='1')
{
	$DB->BeginTrans();
	$DB->Execute('DELETE FROM aliases WHERE id = ?', array($id));
	$DB->Execute('DELETE FROM aliasassignments WHERE aliasid = ?', array($id));
	$DB->CommitTrans();
}

$SESSION->redirect('?'.$SESSION->get('backto'));

?>
